This case study offers a walkthrough of the solution using real-world loan application event logs. It leverages the work that has been published by Bautista, Wangikar, and Akbar, see [Resources](article:9).

# Data

The data was sourced from the BPIC Challenge 2012 ([Resources](article:9)). It is a XES file of real-life event logs from a loan application process within a Dutch Financial Institute. See the Appendix of this article for details on how we preprocessed the data for use in this project.

The analyst's goal is to untangle the data, create insights into how the process behaves in reality, and identify potential inefficiencies that can be rectified. We will highlight in the following sections the kind of insights that are possible from this kind of dataset, drawing our inspiration from the Challenge and associated work.

The [Dataiku Application](article:7) serves as the starting point for any Process Mining project in Dataiku. To load a dataset, simply drag and drop the log file next to 'Upload Logs'. Use the Upload File 'UPLOAD' button to begin loading your files into the application.

The dataset which we have loaded for this walkthrough contains the following columns:

- case_id: Case ID
- step: name of the activity
- start_timestamp: timestamp of the activity
- end_timestamp: end timestamp of the activity
- amount_requested: amount requested by the applicant
- case_start_date: start time of the case
- resource: resource that performed the activity (human or machine)

Once the file has been Loaded, we Refresh the page using the REFRESH button. We are now ready to link the columns into the Process Mining tool. For the walkthrough data we will link the as follows:

- Case ID: case_id
- Activity: step
- Timestamp: start_timestamp
- End Timestamp: end_timestamp
- Select Columns: we have decided to keep amount_requested and step. Notice that the latter is already being used as the Activity column. By loading it 'again' as a Selected Column we will be able to easily filter only traces that contain a given activity.

![Dataiku Application.png](57QfMGfaujwl)

Finally, we Build the Flow using the BUILD FLOW button and, once that is complete, we can open the Application via the OPEN WEBAPP button (or select it in the menu along the top of the screen, under 'Webapps').

# Insights

We will use the Process Mining Application to analyze the data and uncover insights. For more complex projects, or as part of broader data explorations, you might leverage Dataiku's many other analytical tools including data wrangling and charting.

## Initial Cleaning of Data

When landing on the Application, a graph similar to the one below is displayed. No Filters are defined, and the Variants filter is set at the default value of 10. As shown in the description above the visualization, the filtered number of cases is the same as the total number of cases, however only half are displayed as this corresponds to the 10 most frequent variants. From this, we can conclude that almost half of the traces are contained in those 10 variants.

One initial observation that can be made from this graph is that some arrows are looping back to the same activity, which is insight but also a source of potential clutter in our analysis because each of these transitions creates unique Variants. 

Another early observation is that the A_PARTLYSUBMITTED node is always preceded by the A_SUBMITTED node. We can see this simply by clicking on the A_PARTLYSUBMITTED node and reviewing the insights from the pop-up window.

Given these two initial insights, we can simplify our analysis by removing the 'looping back on self' Variants via the Remove Self-Transition Filter, and by removing the A_PARTLYSUBMITTED activity using the Excluded Activities Filters. 

Although not a focus of this specific walkthrough, we could of course take these initial insights and use them to inform a separate workstream where we might investigate what types of cases ‘loop back on’ themselves, or what the A_PARTLYSUBMITTED activity consists of. Both of these workstreams can be effectively handled via the same Process Mining Solution and may be of great interest to the business or operational teams.

By this part of the walkthrough we have already overcome two of the most common hindrances when teams first attempt to tackle process data logs:

Firstly, teams can find an unfamiliar data type or an initially complicated dataset consisting of many columns of unclear value difficult to handle. The Application makes it possible to quickly load such files, connect the relevant columns, and keep additional columns of interest for later review. It also makes it easy to 'start again' with a different set of columns, an updated data file, or different selections. 

Secondly, teams can find that when they first load their logs they are confronted with an impenetrable tangle of hundreds of lines connecting hundreds of activities. This can immediately stop any further progress or insight. By offering the analyst Variant and Filter options, Dataiku ensures analysis can continue uninterrupted while giving power and flexibility to find patterns and cases of interest.

![Case Study 1.png](LwSEkddMklgk)

Once selected, we can commit the modifications by clicking REMOVE EXCLUDED ACTIVITIES FROM DATASET and refreshing the page. Upon doing so, we will obtain the following graph. With these changes made the set of Variants also changes and now the same '10 most common' Variants filter shows more activities and is providing us a deeper and more effective insight into the process.

![Case Study 2.png](ATrkHTNosYIq)

Based on prior analyses performed in the sources that inform this walkthrough, we know there are other activities we might find it useful to exclude. In a real-world scenario, such exclusions are likely to be informed by consultation with subject matter experts, operators, and managers. The below graph shows traces that contain O_SELECTED or O_CREATED activities. With our Time-Frequency toggle set to Time we observe that neither of these activities is notable:

- O_CREATED is always followed immediately by O_SENT
- O_SELECTED has immediate transitions with O_FINALIZED, and also has O_SENT following it after a few seconds.

We can further refine our analysis by filtering out these two additional elements.

![Case Study 3.png](nbh2Ol5YQ1gB)

Similar observations are made for O_ACCEPTED, A_REGISTERED, and A_ACTIVATED which are activities that have immediate transitions between each other, and are entangled with the more informative A_APPROVED activity. These are also filtered out.

![Case Study 4.png](h48Hc91NHfxF)

## Identifying Processes

After this initial clarification of the processes, we are able to start investigating the most frequent processes of interest. An excellent way to start is by defining start or end activities that are known to be of particular importance. For this walkthrough, we will begin by setting the 'End Activity' selection to the A_APPROVED activity. This will let us observe more closely those traces that end with successful application approval.

As shown below the A_APPROVED traces move mostly linearly through various activities to O_SENT. At this point workflows vary, and include various iterations of the following working activities:

- Calls by agents to the client to add missing information to the application
- Calls by agents to the clients after sending offers
- Assessment of the application

After various combinations of these paths, the process concludes with an Approval.

![Approved Process.png](OefwnbB3QwB3)

An excellent next step would be to 'contrast' this result with another process of interest, in this case, those that result in an application being Declined. We can achieve this by simply replacing the 'End Activity' with A_DECLINED. 

We can immediately see an insightfully different pattern. Almost half of all ultimately Declined traces go directly from A_SUBMITTED to A_DECLINED. Another one-third move from A_SUBMITTED to "W_Fixing Incoming Lead" and then on to the same result. A very small share (less than 1%) is Declined after being "Assessed for Fraud". The remainder is split into two-thirds Declined after filling in application materials following pre-acceptance, with the last segment undergoing a multi-step process (including the A_ACCEPTED activity) before ultimately being Declined.

These various pathways open interesting avenues for further investigation: is it expected that any case assessed for Fraud will always be Rejected? Is it expected that such a large share of leads should need to enter the 'Fixing incoming lead' activity, and how does this compare with the share going to the same process which ultimately ends up as Approved?  These questions and more can be readily tackled via conformance checks and individual tracing, as outlined below. 

![Declined Process.png](dvjgwuzhQx32)

## Conformance Checks

The processes defined above (via the combination of Filters and the number of Variants included) can be easily saved by selecting 'Save current process' from the Reference Process dropdown menu. Once saved we can select this process or any other previously saved processes and investigate them further using the Conformance Checks and Individual Traces tabs along the top of the Application. 

On first selecting the Conformance Checks tab the window will be empty. To compute the checks click Action in the Reference Process section and select 'Run Conformance Checks'.

By selecting the previously saved 'Approved' process we defined above, we can observe very high conformance over time. Note that we do not see 100% conformance, in part because the saved process only included the '10 most common' Variants. The result is also adjusted slightly via the use of statistical calculations via the Inductive Miner described [here](article:3) which will drop some very rare activities from the calculation. While we see very high conformance, the outliers are perhaps of greatest interest to us. We will be able to investigate those for insights in the Individual Traces tab. 

![Approved Checks.png](bbPALl8ZC40o)

A similar analysis can be run on the traces from the 'Declined' process we identified. The conformance scores remain very high, often at full conformance, though we notice some measurable drops towards the latest periods of our data set. This suggests the possibility of an underlying change to the process, perhaps for the worse. Trace investigations can reveal more. This is an excellent opportunity to enrich the analysis further with subject-matter expertise and consultation with operators. 

![Declined Checks.png](DbqeTIGRFsTY)

Before moving on, note that these Conformance Charts not only allow us to subsequently identify individual traces that we might find of interest but can also be used to consistently monitor one or many processes over time to ensure any process improvements we put into place are having the desired impact. Checks of this kind can also be powerful as KPIs for operations teams.

## Individual Traces

Traces can be investigated individually via the Individual Traces tab. 

Here we will investigate traces that do not fit well the previously defined processes. Other interesting analytical approaches could be, for example, finding a selection of real-world traces that illustrate 'best in class' operational experience, or finding traces that have interesting properties in their Additional Columns such as 'amount requested'.

  We can begin by looking at traces that fit the 'Approved' process pattern least closely. As before we can select the relevant saved process in the 'Compare Reference Process' dropdown. A table will appear on the right-hand side showing all Traces and their calculated Fitness. Scores of 1.0 are perfect matches to the process. In this example a trace with the score of 0.92 is selected, which is of particular interest since the 'amount requested' is high. We can click on any part of the row for this Trace to see below the table a graph representing this specific Trace. We can visually note the differences, for example, that this Trace involves 'cycling' back A_ACCEPTED and 'W_Assessing Fraud' after 'W_Filling in information for the application' which was not seen in the 'Approved process'. Since we are now looking at one specific Trace (i.e., the specific path taken by one specific Case) and have its unique Case ID we are able to undertake any amount of follow-up or in-depth investigations. To kick-start this investigation we can open the [process_conformance_checks](dataset:process_conformance_checks) dataset and filter on the selected Case ID, revealing which Transitions and Activities are most impacting the low Fitness score (in this case it is 'W_Filling in information for the application' twice).

![Approved Individual.png](xrWsTjuvH20C)

A similar analysis can be performed relative to the 'Declined' process. A Notably troublesome transition here is 'W_Assessing fraud'. 

![Declined Individual.png](YG8xK1WbQ2fM)

# Conclusion

With no coding required, and all data processing handled easily within Dataiku, we have been able to define two relevant processes and through them have already gained a depth of understanding of the underlying process. We can share high-level, illustrative and individual insights whenever needed. As a result, we are very well positioned to discuss our findings with management or operations teams, leverage subject matter expertise through informed and clear questions or clarifications, and integrate additional data sets or statistical checks to enrich our analysis further. We could also deploy conformance checking as a routine part of our future reviews of the success of our process optimization efforts. 

Powerful machine learning or AI-driven insights and predictions are also immediately accessible to us, via Dataiku's powerful capabilities and integrations.

# Data Appendix

To improve understanding we have prior to loading the source data made the following modifications: translated the activities' names from Dutch to English, removed activities starting with W (working activities) where lifecycle:transition is equal to SCHEDULE, removed the lifecycle:transition column (after applying the filter on working activities, this column no longer adds additional information to the analysis). To create the end_timestamp column, lines of log with lifecycle:transition equal to complete are joined back to their starting point. It happened in the logs that the end_timestamp were greater than the timestamp of the next activity, we cap the end_timestamp to the closest following timestamp to avoid any overlapping activity.

The data was initially loading in the XES format and converted to CSV using a python recipe with a function provided in the pm4py package.

After conversion, a random sample of the data is loaded for the initial analysis. This ensures that calculations can occur rapidly during this preliminary investigative process. 


